'''Simple data loader module.

Loads data files from the "data" directory shipped with a game.

Enhancing this to handle caching etc. is left as an exercise for the reader.
'''
import pygame
import math
import os


data_py = os.path.abspath(os.path.dirname(__file__))
data_dir = os.path.normpath(os.path.join(data_py, '..', 'data'))
hotkeys = [ 1,2,3,4,5,6,7,8,9,0 ]
font_map = {}

def filepath(filename):
    '''Determine the path to a file in the data directory.
    '''
    return os.path.join(data_dir, filename)

def load(filename, mode='rb'):
    '''Open a file in the data directory.

    "mode" is passed as the second arg to open().
    '''
    return open(os.path.join(data_dir, filename), mode)

def load_image(filename):
    fullpath = filepath(filename)
    img = pygame.image.load(fullpath)
    img = img.convert()
    return img

def load_font(filename,size):
    fullpath = filepath(filename)
    if (fullpath,size) in font_map:
        return font_map[ (fullpath,size) ]
    else:
        #print fullpath
        loaded = pygame.font.Font(fullpath,size)
        font_map[ (fullpath,size) ] = loaded
        return loaded

def distance(tuple1, tuple2):
    x1,y1 = tuple1
    x2,y2 = tuple2
    return math.sqrt( math.pow(x1-x2,2) + math.pow(y1-y2,2))

def sign(x):
    if x < 0:
        return -1
    elif x > 0:
        return 1
    return 0