'''Game main module.

Contains the entry point used by the run_game.py script.

Feel free to put all your game code here, or in other modules in this "lib"
directory.
'''
import pygame

import data
import engine
import items
import playing
import rpg
import dialogs
import glob
import pickle

class TitleState(engine.State):
    def __init__(self, driver):
        engine.State.__init__(self,driver)
        title = data.load_image("title.png")
        self.title = pygame.transform.scale(title,driver.screen.size)
        self.load = None
        
        self.newgame = engine.Button("(B)egin the ascent",self.newgame,'b')
        self.newgame.rect.topleft = ( 3, 30 )
        self.add(self.newgame)
        
        y = self.newgame.rect.bottom + 3
        self.resume = engine.Button("(R)esume your quest", self.resume, 'r')
        self.resume.rect.topleft = [ 3, y ]
        self.add(self.resume)
        
    def activate(self):
        if self.load:
            chosen = self.load.chosen
            if self.load.chosen != None and self.load.chosen < len(self.files):
                infile = open(self.files[self.load.chosen])
                pgs = pickle.load(infile)
                infile.close()
                pgs.driver = self.driver
                self.driver.push(pgs)
        
    def newgame(self, button):
        
        cs = dialogs.CharacterState(self)
        self.driver.push(cs)
        
    def paint(self,screen):
        screen.blit(self.title, (0,0) )
        engine.State.paint(self,screen)
    
    def resume(self, button):
        self.files = glob.glob('./*.sav')
        self.load = dialogs.ChooseFromTenState(self,self.files,"Which game?")
        self.driver.push(self.load)
    
    def update(self,delay):
        pass

def main():
    pygame.init()
    screen = engine.Screen()
    screen.caption = "The Tower of Trials"
    e = engine.Engine(screen)
    
    title = TitleState(e)
    e.push(title)
    e.run()
