
class Skill(object):
    def __init__(self, name):
        self.name = name
        self.enabled = True
        
    def apply(self, pc):
        raise NotImplementedError
    
    def isEnabled(self):
        return self.enabled
    
    def __str__(self):
        return self.name
        
class CooldownSkill(Skill):
    def __init__(self, name,cooldownInMS):
        Skill.__init__(self, name)
        self.maxCooldown = cooldownInMS
        self.cooldown = self.maxCooldown
        
    def apply(self, pc):
        raise NotImplementedError
            
    def isEnabled(self):
        return self.cooldown >= self.maxCooldown
    
    def reset(self):
        self.cooldown = 0
    
    def update(self, delay):
        if not self.isEnabled():
            self.cooldown += delay
    
    def __str__(self):
        if self.isEnabled():
            return self.name
        else:
            secs = (self.maxCooldown - self.cooldown) / 1000
            return self.name + " (%ds)" % secs

class OngoingCooldownSkill(CooldownSkill):
    def __init__(self, name, cooldownInMS, lastsInMS):
        CooldownSkill.__init__(self,name, cooldownInMS)
        self.lastsUntil = lastsInMS
        self.unapplied = False
        
    def apply(self, pc):
        self.unapplied = False
        self.pc = pc
        
    def unapply(self, pc):
        raise NotImplementedError
    
    def update(self, delay):
        CooldownSkill.update(self,delay)
        #print not self.isEnabled, not self.unapplied, (not self.isEnabled) and (not self.unapplied)
        if (not self.isEnabled()) and (not self.unapplied):
            if self.cooldown > self.lastsUntil:
                self.unapplied = True
                self.unapply(self.pc)
            
class PowerAttack(CooldownSkill):
    def __init__(self, adjustment):
        name = "Power Attack %d" % adjustment
        CooldownSkill.__init__(self, name, 4000+2000*adjustment)
        self.adjustment = adjustment
        
    def apply(self, pc):
        if self.isEnabled() and pc.target:
            self.reset()
            pc.tilemap.log.postMessage("%s uses %s!" % (pc.name, self.name))
            pc.attack(-self.adjustment, self.adjustment)
            
class Dodge(OngoingCooldownSkill):
    def __init__(self):
        name = "Dodge"
        OngoingCooldownSkill.__init__(self, name, 45000, 15000)
        
    def apply(self, pc):
        self.reset()
        OngoingCooldownSkill.apply(self,pc)
        pc.buffAC(1)
        pc.tilemap.log.postMessage("%s uses %s." % (pc.name, self.name))
        
    def unapply(self, pc):
        pc.tilemap.log.postMessage("%s's %s wears off." % (pc.name, self.name))
        pc.buffAC(-1)